summaryrefslogtreecommitdiffstats
path: root/src/fastd.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/fastd.h')
-rw-r--r--src/fastd.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/fastd.h b/src/fastd.h
index 554a982..fcd8676 100644
--- a/src/fastd.h
+++ b/src/fastd.h
@@ -79,8 +79,8 @@ struct fastd_protocol {
/** Checks if a peer configuration is valid and a connection may be established */
bool (*peer_check)(fastd_peer_config_t *peer_conf);
- /** Checks if a temporary peer is valid and a connection may be established */
- bool (*peer_check_temporary)(fastd_peer_t *peer);
+ /** Checks if a dynamic peer is valid and a connection may be established */
+ bool (*peer_check_dynamic)(fastd_peer_t *peer);
/** Sends a handshake to the given peer */